@@ -1201,7 +1201,7 @@ medication.post(
   '/import-ongoing',
   asyncHandler(async (req, res) => {
     const { models, db } = req;
-    const { Encounter, Prescription, EncounterPrescription, PatientOngoingPrescription } = models;
+    const { Encounter, Prescription, EncounterPrescription, PatientOngoingPrescription, MedicationAdministrationRecord } = models;
 
     const { prescriptionIds, prescriberId, encounterId } =
       await importOngoingMedicationsSchema.parseAsync(req.body);
@@ -1274,6 +1274,8 @@ medication.post(
         prescription.discontinuedDate = getCurrentDateTimeString();
         await prescription.save({ transaction });
 
+        await MedicationAdministrationRecord.generateMedicationAdministrationRecords(newPrescription);
+
         newPrescriptions.push(newPrescription);
       }
 
